/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *     "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache" or
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
/*
 * JSPViewProcessor.java
 *
 * Created on January 27, 2003, 5:37 PM
 */
package org.apache.jetspeed.portal.portlets.viewprocessor;


// Ecs
import org.apache.ecs.ElementContainer;
import org.apache.ecs.StringElement;


// Jetspeed portal
import org.apache.jetspeed.portal.Portlet;
import org.apache.jetspeed.portal.portlets.*;
import org.apache.jetspeed.portal.portlets.GenericMVCContext;
import org.apache.jetspeed.portal.portlets.viewprocessor.*;
import org.apache.jetspeed.services.TemplateLocator;

import org.apache.turbine.services.TurbineServices;
import org.apache.turbine.services.jsp.JspService;
import org.apache.turbine.util.Log;

// Turbine util
import org.apache.turbine.util.RunData;


/**
 *
 * @author  tkuebler
 */
public class JSPViewProcessor
    implements ViewProcessor
  {

    /** Creates a new instance of JSPViewProcessor */
    public JSPViewProcessor()
      {
      }

    public Object processView(GenericMVCContext context)
      {

        String template = (String) context.get("template");
        Log.info("JSPViewProcessor - processing template " + template);

        try
          {

            //
            // gets the jsp page from the xreg configuration
            // NOTE: wouldn't it be better to get the param from the PSML?
            //
            if (-1 == template.indexOf(".jsp"))
              {
                template = template + ".jsp";
              }

            Log.info("JSPViewProcessor - locating template - " + ((RunData) context.get("data")).toString() + " - " + template);

            //we use the template locator to translate the template
            String locatedTemplate = TemplateLocator.locatePortletTemplate((RunData) context.get("data"), template);
            Log.info("JSPViewProcessor - located template: " + locatedTemplate);

            JspService service = (JspService) TurbineServices.getInstance().getService(JspService.SERVICE_NAME);

            // this is only necessary if we ddon't run in a JSP page environment
            // but better be safe than sorry...
            service.addDefaultObjects((RunData) context.get("data"));

            // Allow access to portlet from .jsp template
            ((RunData) context.get("data")).getRequest().setAttribute("portlet", (Portlet) context.get("portlet"));

            // put context in attribute so you can get to it from .jsp template
            ((RunData) context.get("data")).getRequest().setAttribute("context", context);

            // Add js_peid out of convenience
            ((RunData) context.get("data")).getRequest().setAttribute("js_peid", ((Portlet) context.get("portlet")).getID());

            // handle request
            service.handleRequest((RunData) context.get("data"), locatedTemplate);
          }
        catch (Exception e)
          {

            String message = "JspViewProcessor: Could not include the following JSP Page:  [" + template + "] :\n\t" + 
                             e.getMessage();
            Log.error(message, e);

            return new StringElement(message);
          }

        return new ElementContainer();
      }

    /** Process the template passed in the context
     * (context.get("template")).  Invoked by the GenericMVCPortlet
     * after action handling to process the template type
     * in question.
     *
     */
    public void init(Portlet portlet)
      {
      }
  }
